@@ -3,22 +3,31 @@ from terminusgps.wialon.items.base import WialonBase
 
 
 class WialonResource(WialonBase):
-    def create(self, **kwargs) -> int | None:
-        if not kwargs.get("creator_id"):
-            raise ValueError("'creator_id' is required for creation.")
-        if not kwargs.get("name"):
-            raise ValueError("'name' is required for creation.")
-        if not kwargs.get("flags"):
-            kwargs["flags"] = flags.DATAFLAG_UNIT_BASE
+    def create(self, creator_id: str | int, name: str) -> int | None:
+        """
+        Creates a new Wialon resource.
+
+        :param creator_id: A Wialon user id.
+        :type creator_id: :py:obj:`int` | :py:obj:`str`
+        :param name: A name for the resource.
+        :type name: :py:obj:`str`
+        :raises ValueError: If ``creator_id`` is not a digit.
+        :raises WialonError: If something goes wrong with Wialon.
+        :returns: The Wialon id for the new resource, if it was created.
+        :rtype: :py:obj:`int` | :py:obj:`None`
+
+        """
+        if isinstance(creator_id, str) and not creator_id.isdigit():
+            raise ValueError(f"'creator_id' must be a digit, got '{creator_id}'.")
 
         response = self.session.wialon_api.core_create_resource(
             **{
-                "creatorId": kwargs["creator_id"],
-                "name": kwargs["name"],
-                "dataFlags": kwargs["flags"],
+                "creatorId": creator_id,
+                "name": name,
+                "dataFlags": flags.DATAFLAG_UNIT_BASE,
             }
         )
-        return response.get("item", {}).get("id")
+        return int(response.get("item", {}).get("id")) if response.get("item") else None
 
     def delete(self) -> None:
         """
@@ -61,7 +70,7 @@ class WialonResource(WialonBase):
         response = self.session.wialon_api.core_search_item(
             **{"id": self.id, "flags": flags.DATAFLAG_RESOURCE_BILLING_PROPERTIES}
         )
-        return response.get("item", {}).get("bact") == self.id
+        return int(response.get("item", {}).get("bact")) == self.id
 
     def is_migrated(self, unit: WialonBase) -> bool:
         """
